# Security Policy

This document outlines the security policy for the Datadog Python client library (aka Python tracer) and what to do if you discover a security vulnerability in the project.
Most notably, please do not share the details in a public forum (such as in a discussion, issue, or pull request) but instead reach out to us with the details.
This gives us an opportunity to release a fix for others to benefit from by the time details are made public.

## Supported Versions

We accept vulnerability submissions for the [currently maintained release](https://github.com/DataDog/dd-trace-py/releases).

## Reporting a Vulnerability

If you discover a vulnerability in the Datadog Python client library (or any Datadog product for that matter) please submit details to the following email address:

* [security@datadoghq.com](mailto:security@datadoghq.com)
